==> apache-ignite-2.16.0-src.zip: apache-ignite-2.16.0-src/modules/indexing/src/test/java/org/apache/ignite/cache/query/IndexQueryTestSuite.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.cache.query;

import org.junit.runner.RunWith;
import org.junit.runners.Suite;

/**
 * Suite with tests for {@link IndexQuery}.
 */
@RunWith(Suite.class)
@Suite.SuiteClasses({
    IndexQueryAllTypesTest.class,
    IndexQueryFailoverTest.class,
    IndexQueryFilterTest.class,
    IndexQueryInlineSizesTest.class,
    IndexQueryKeepBinaryTest.class,
    IndexQueryLocalTest.class,
    IndexQueryQueryEntityTest.class,
    IndexQueryAliasTest.class,
    IndexQuerySqlIndexTest.class,
    IndexQueryRangeTest.class,
    IndexQueryPartitionTest.class,
    IndexQueryCacheKeyValueFieldsTest.class,
    IndexQueryCacheKeyValueEscapedFieldsTest.class,
    IndexQueryCacheKeyValueTransformedFieldsTest.class,
    IndexQueryWrongIndexTest.class,
    MultifieldIndexQueryTest.class,
    MultiTableIndexQuery.class,
    RepeatedFieldIndexQueryTest.class,
    ThinClientIndexQueryTest.class,
    RepeatedFieldIndexQueryTest.class,
    IndexQueryInCriterionTest.class,
    IndexQueryInCriterionDescTest.class,
    IndexQueryLimitTest.class
})
public class IndexQueryTestSuite {
}

==> apache-ignite-2.17.0-src.zip: apache-ignite-2.17.0-src/modules/indexing/src/test/java/org/apache/ignite/cache/query/IndexQueryTestSuite.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.cache.query;

import org.junit.runner.RunWith;
import org.junit.runners.Suite;

/**
 * Suite with tests for {@link IndexQuery}.
 */
@RunWith(Suite.class)
@Suite.SuiteClasses({
    IndexQueryAllTypesTest.class,
    IndexQueryFailoverTest.class,
    IndexQueryFilterTest.class,
    IndexQueryInlineSizesTest.class,
    IndexQueryKeepBinaryTest.class,
    IndexQueryLocalTest.class,
    IndexQueryQueryEntityTest.class,
    IndexQueryAliasTest.class,
    IndexQuerySqlIndexTest.class,
    IndexQueryRangeTest.class,
    IndexQueryPartitionTest.class,
    IndexQueryCacheKeyValueFieldsTest.class,
    IndexQueryCacheKeyValueEscapedFieldsTest.class,
    IndexQueryCacheKeyValueTransformedFieldsTest.class,
    IndexQueryWrongIndexTest.class,
    MultifieldIndexQueryTest.class,
    MultiTableIndexQuery.class,
    RepeatedFieldIndexQueryTest.class,
    ThinClientIndexQueryTest.class,
    RepeatedFieldIndexQueryTest.class,
    IndexQueryInCriterionTest.class,
    IndexQueryInCriterionDescTest.class,
    IndexQueryLimitTest.class,
    IndexQueryPaginationTest.class
})
public class IndexQueryTestSuite {
}
